@@ -2,8 +2,7 @@ __all__ = ['ISBNToolsHTTPError', 'ISBNToolsURLError',
            'DataNotFoundAtServiceError',
            'ServiceIsDownError', 'DataWrongShapeError',
            'NotValidMetadataError', 'Metadata', 'stdmeta',
-           'WEBService', 'WEBQuery', 'WCATQuery',
-           'WCATEdQuery', 'GOOBQuery', 'ISBNDBQuery', 'OPENLQuery',
+           'WEBService', 'WEBQuery',
            'ISBNToolsHTTPError', 'ISBNToolsURLError', 'vias',
            'NoDataForSelectorError', 'ServiceIsDownError',
            'DataWrongShapeError', 'NotValidMetadataError',
@@ -13,11 +12,6 @@ __all__ = ['ISBNToolsHTTPError', 'ISBNToolsURLError',
 
 from .webservice import WEBService
 from .webquery import WEBQuery
-from .wcat import WCATQuery
-from .wcated import WCATEdQuery
-from .goob import GOOBQuery
-from .isbndb import ISBNDBQuery
-from .openl import OPENLQuery
 from .exceptions import (ISBNToolsHTTPError, ISBNToolsURLError,
                          DataNotFoundAtServiceError,
                          NoDataForSelectorError, ServiceIsDownError,
