@@ -4,7 +4,6 @@ Private helper functions
 """
 
 import re
-import functools
 
 
 def normalize_space(item):
@@ -26,12 +25,3 @@ def titlecase(s):
     """
     return re.sub(r"[A-Za-z]+('[A-Za-z]+)?",
                   lambda m: m.group(0)[0].upper() + m.group(0)[1:], s)
-
-
-def compose1arg(*functions):
-    """
-    Composes one-argument functions
-
-    Very handy for functional techniques!
-    """
-    return functools.reduce(lambda f, g: lambda x: f(g(x)), functions)
